bump

package
v0.0.0-...-e592ac4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2021 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Build

func Build(v semver.Version, build string) (semver.Version, error)

Build is for metadata without precedence

func Major

func Major(v semver.Version) (semver.Version, error)

Major is for API incompatible changes

func Minor

func Minor(v semver.Version) (semver.Version, error)

Minor is for when you add functionality in a backwards-compatible manner

func Patch

func Patch(v semver.Version) (semver.Version, error)

Patch is for when you make backwards-compatible bug fixes

func Prerelease

func Prerelease(v semver.Version, pre string) (semver.Version, error)

Prerelease is for versions have a lower precedence than the associated normal version

Types

This section is empty.

Jump to